Method: PunkBlocks#svgFromIDs

Defined in:
lib/ethlite/contracts/punk_blocks.rb

#svgFromIDs(_ids) ⇒ Object

function svgFromIDs

svgFromIDs returns the svg data as a string
       e.g. [9,55,99]
       One of the elements must be must be a layer 0 block.
       This element decides what version of image to use for the higher layers
       (dataMale or dataFemale)
     @param _ids uint256 ids of an attribute, by it's index of creation


134
135
136
# File 'lib/ethlite/contracts/punk_blocks.rb', line 134

def svgFromIDs(_ids)
  do_call("svgFromIDs", _ids)
end