Method: PunkBlocks#svgFromKeys
- Defined in:
- lib/ethlite/contracts/punk_blocks.rb
#svgFromKeys(_attributeKeys) ⇒ Object
function svgFromKeys
svgFromKeys returns the svg data as a string
@param _attributeKeys a list of attribute names that have been hashed,
eg keccak256("Male 1"), keccak256("Goat")
must have at least 1 layer 0 attribute (eg. keccak256("Male 1")) which
decides what version of image to use for the higher layers
(dataMale or dataFemale)
e.g. ["0x9039da071f773e85254cbd0f99efa70230c4c11d63fce84323db9eca8e8ef283",
"0xd5de5c20969a9e22f93842ca4d65bac0c0387225cee45a944a14f03f9221fd4a"]
149 150 151 |
# File 'lib/ethlite/contracts/punk_blocks.rb', line 149 def svgFromKeys(_attributeKeys) do_call("svgFromKeys", _attributeKeys) end |